# frozen_string_literal: true

require 'test_helper'
require 'rails/generators/test_case'
require 'generators/test_unit/input/input_generator'

module TestUnit
  module Generators
    class InputGeneratorTest < Rails::Generators::TestCase
      tests InputGenerator
      destination File.expand_path('tmp')
      setup :prepare_destination

      test 'generate Input test file' do
        run_generator(['article'])

        assert_file 'test/inputs/article_input_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ArticleInputTest < ActiveSupport::TestCase
          end
        RUBY
      end

      test 'generate Input test file when suffix is specified' do
        run_generator(['ArticleInput'])

        assert_file 'test/inputs/article_input_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ArticleInputTest < ActiveSupport::TestCase
          end
        RUBY
      end

      test 'generate namespaced Input test file' do
        run_generator(['articles/article'])

        assert_file 'test/inputs/articles/article_input_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          module Articles
            class ArticleInputTest < ActiveSupport::TestCase
            end
          end
        RUBY
      end
    end
  end
end
