# frozen_string_literal: true

require 'test_helper'
require 'rails/generators/test_case'
require 'generators/test_unit/install/install_generator'

module TestUnit
  module Generators
    class InstallGeneratorTest < Rails::Generators::TestCase
      tests InstallGenerator
      destination File.expand_path('tmp')
      setup :prepare_destination

      test 'generate directories' do
        run_generator

        assert_file 'test/inputs/.keep'
        assert_file 'test/repositories/.keep'
      end

      test 'transform existing Model tests into Record tests' do
        create_file 'test/models/application_record_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ApplicationRecordTest < ActiveSupport::TestCase
          end
        RUBY

        create_file 'test/models/article_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ArticleTest < ActiveSupport::TestCase
          end
        RUBY

        create_file 'test/models/users/user_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          module Users
            class UserTest < ActiveSupport::TestCase
            end
          end
        RUBY

        Thor::LineEditor.stub(:readline, 'yes') { run_generator }

        assert_file 'test/records/application_record_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ApplicationRecordTest < ActiveSupport::TestCase
          end
        RUBY

        assert_file 'test/records/article_record_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ArticleRecordTest < ActiveSupport::TestCase
          end
        RUBY

        assert_file 'test/records/users/user_record_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          module Users
            class UserRecordTest < ActiveSupport::TestCase
            end
          end
        RUBY

        assert_no_file 'test/models/application_record_test.rb'
        assert_no_file 'test/models/article_test.rb'
        assert_no_file 'test/models/users/user_test.rb'
      end

      test 'does not transform existing Model tests into Record tests when user answers no' do
        create_file 'test/models/application_record_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ApplicationRecordTest < ActiveSupport::TestCase
          end
        RUBY

        create_file 'test/models/article_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ArticleTest < ActiveSupport::TestCase
          end
        RUBY

        Thor::LineEditor.stub(:readline, 'no') { run_generator }

        assert_file 'test/models/application_record_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ApplicationRecordTest < ActiveSupport::TestCase
          end
        RUBY

        assert_file 'test/models/article_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ArticleTest < ActiveSupport::TestCase
          end
        RUBY

        assert_no_directory 'test/records'
      end

      private

      def create_file(name, content)
        path = File.expand_path(name, destination_root)
        mkdir_p(File.dirname(path))
        File.write(path, content)
      end
    end
  end
end
