# frozen_string_literal: true

require 'test_helper'
require 'rails/generators/test_case'
require 'generators/test_unit/record/record_generator'

module TestUnit
  module Generators
    class RecordGeneratorTest < Rails::Generators::TestCase
      tests RecordGenerator
      destination File.expand_path('tmp')
      setup :prepare_destination

      test 'generate Record test file' do
        run_generator(['article'])

        assert_file 'test/records/article_record_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ArticleRecordTest < ActiveSupport::TestCase
          end
        RUBY
      end

      test 'generate Record test file when suffix is specified' do
        run_generator(['ArticleRecord'])

        assert_file 'test/records/article_record_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ArticleRecordTest < ActiveSupport::TestCase
          end
        RUBY
      end

      test 'generate namespaced Record test file' do
        run_generator(['articles/article'])

        assert_file 'test/records/articles/article_record_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          module Articles
            class ArticleRecordTest < ActiveSupport::TestCase
            end
          end
        RUBY
      end
    end
  end
end
