# frozen_string_literal: true

require 'test_helper'
require 'rails/generators/test_case'
require 'generators/test_unit/repository/repository_generator'

module TestUnit
  module Generators
    class RepositoryGeneratorTest < Rails::Generators::TestCase
      tests RepositoryGenerator
      destination File.expand_path('tmp')
      setup :prepare_destination

      test 'generate Repository test file' do
        run_generator(['article'])

        assert_file 'test/repositories/article_repository_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ArticleRepositoryTest < ActiveSupport::TestCase
          end
        RUBY
      end

      test 'generate Repository test file when suffix is specified' do
        run_generator(['ArticleRepository'])

        assert_file 'test/repositories/article_repository_test.rb', <<~RUBY
          # frozen_string_literal: true

          require 'test_helper'

          class ArticleRepositoryTest < ActiveSupport::TestCase
          end
        RUBY
      end

      test 'generate namespaced Repository test file' do
        run_generator(['articles/article'])

        assert_file 'test/repositories/articles/article_repository_test.rb',
          <<~RUBY
            # frozen_string_literal: true

            require 'test_helper'

            module Articles
              class ArticleRepositoryTest < ActiveSupport::TestCase
              end
            end
          RUBY
      end
    end
  end
end
