# frozen_string_literal: true

require 'test_helper'
require 'rails/generators/test_case'
require 'generators/upgrow'

module Upgrow
  module Generators
    class GeneratorHelperTest < Rails::Generators::TestCase
      class SampleGenerator < Rails::Generators::Base
        include Helper

        attr_accessor :file_name, :class_path, :output_buffer

        def do_all_the_things
          move_file(
            'app/models/article.rb', 'app/models/articles/my_article.rb'
          )
        end
      end

      tests SampleGenerator
      destination File.expand_path('../../../tmp', __dir__)
      setup :prepare_destination

      test '#move_file moves the original path to destination' do
        create_file 'app/models/article.rb', <<~RUBY
          class Article < ApplicationModel
          end
        RUBY

        run_generator

        assert_file 'app/models/articles/my_article.rb', <<~RUBY
          class Article < ApplicationModel
          end
        RUBY

        assert_no_file 'app/models/article.rb'
      end

      test '.base_root is the generators directory' do
        expected = File.expand_path('lib/generators')
        assert_equal expected, SampleGenerator.base_root
      end

      test '#class_name is the camelized file name' do
        generator.file_name = 'my_file_name'
        assert_equal 'MyFileName', generator.class_name
      end

      test '#module_namespacing outputs the given block when class path is empty' do
        generator.output_buffer = String.new
        generator.class_path = []

        generator.module_namespacing { generator.send(:concat, 'hello') }
        assert_equal('hello', generator.output_buffer)
      end

      test '#module_namespacing namespaces the given block with the class path' do
        generator.output_buffer = String.new
        generator.class_path = ['posts', 'tags']

        generator.module_namespacing { generator.send(:concat, 'hello') }

        expected = <<~RUBY
          module Posts
            module Tags
              hello
            end
          end
        RUBY

        assert_equal(expected, generator.output_buffer)
      end

      private

      def create_file(name, content)
        mkdir_p(File.expand_path(File.dirname(name), destination_root))
        path = File.expand_path(name, destination_root)
        File.write(path, content)
      end
    end
  end
end
