# frozen_string_literal: true

require 'test_helper'
require 'rails/generators/test_case'
require 'generators/upgrow/repository/repository_generator'

module Upgrow
  module Generators
    class RepositoryGeneratorTest < Rails::Generators::TestCase
      tests RepositoryGenerator
      destination File.expand_path('tmp')
      setup :prepare_destination

      test 'generate Repository file' do
        run_generator(['article'])

        assert_file 'app/repositories/article_repository.rb', <<~RUBY
          # frozen_string_literal: true

          class ArticleRepository < ApplicationRepository
          end
        RUBY
      end

      test 'generate Repository when suffix is specified' do
        run_generator(['ArticleRepository'])

        assert_file 'app/repositories/article_repository.rb', <<~RUBY
          # frozen_string_literal: true

          class ArticleRepository < ApplicationRepository
          end
        RUBY
      end

      test 'generate namespaced Repository file' do
        run_generator(['articles/article'])

        assert_file 'app/repositories/articles/article_repository.rb', <<~RUBY
          # frozen_string_literal: true

          module Articles
            class ArticleRepository < ApplicationRepository
            end
          end
        RUBY
      end
    end
  end
end
