# frozen_string_literal: true

require 'test_helper'

module Upgrow
  class ResultTest < ActiveSupport::TestCase
    setup do
      @errors = [:error]
    end

    test '.new returns a Result class with the given members and errors' do
      result_class = Result.new(:user)
      assert_equal([:user, :errors], result_class.members)
    end

    test '.new allows defining errors explicitly' do
      result_class = Result.new(:user, :errors)
      assert_equal([:user, :errors], result_class.members)
    end

    test '.new returns a Result class with only errors when called without arguments' do
      result_class = Result.new
      assert_equal([:errors], result_class.members)
    end

    test '.new does not accept duplicate members' do
      error = assert_raises(ArgumentError) do
        Result.new(:user, :user)
      end

      assert_equal 'duplicate member: user', error.message
    end

    test '.new.new returns a Result populated with the given values' do
      result = Result.new(:user).new(user: 'volmer')
      assert_equal 'volmer', result.user
      assert_empty result.errors
    end

    test '#success? is true when there are no errors' do
      result = Result.new.new
      assert_predicate result, :success?
    end

    test '#success? is false when there are errors' do
      result = Result.new.new(errors: @errors)
      refute_predicate result, :success?
    end
  end
end
